IcoMoon Demo
Description: An Icon Font Generated By IcoMoon.io

# Font Name: icomoon (Glyphs: 515)

# Grid Size: 20

icon-add-to-list
liga:
icon-classic-computer
liga:
icon-controller-fast-backward
liga:
icon-creative-commons-attribution
liga:
icon-creative-commons-noderivs
liga:
icon-creative-commons-noncommercial-eu
liga:
icon-creative-commons-noncommercial-us
liga:
icon-creative-commons-public-domain
liga:
icon-creative-commons-remix
liga:
icon-creative-commons-share
liga:
icon-creative-commons-sharealike
liga:
icon-creative-commons
liga:
icon-document-landscape
liga:
icon-remove-user
liga:
icon-warning
liga:
icon-arrow-bold-down
liga:
icon-arrow-bold-left
liga:
icon-arrow-bold-right
liga:
icon-arrow-bold-up
liga:
icon-arrow-down
liga:
icon-arrow-left
liga:
icon-arrow-long-down
liga:
icon-arrow-long-left
liga:
icon-arrow-long-right
liga:
icon-arrow-long-up
liga:
icon-arrow-right
liga:
icon-arrow-up
liga:
icon-arrow-with-circle-down
liga:
icon-arrow-with-circle-left
liga:
icon-arrow-with-circle-right
liga:
icon-arrow-with-circle-up
liga:
icon-bookmark
liga:
icon-bookmarks
liga:
icon-chevron-down
liga:
icon-chevron-left
liga:
icon-chevron-right
liga:
icon-chevron-small-down
liga:
icon-chevron-small-left
liga:
icon-chevron-small-right
liga:
icon-chevron-small-up
liga:
icon-chevron-thin-down
liga:
icon-chevron-thin-left
liga:
icon-chevron-thin-right
liga:
icon-chevron-thin-up
liga:
icon-chevron-up
liga:
icon-chevron-with-circle-down
liga:
icon-chevron-with-circle-left
liga:
icon-chevron-with-circle-right
liga:
icon-chevron-with-circle-up
liga:
icon-cloud
liga:
icon-controller-fast-forward
liga:
icon-controller-jump-to-start
liga:
icon-controller-next
liga:
icon-controller-paus
liga:
icon-controller-play
liga:
icon-controller-record
liga:
icon-controller-stop
liga:
icon-controller-volume
liga:
icon-dot-single
liga:
icon-dots-three-horizontal
liga:
icon-dots-three-vertical
liga:
icon-dots-two-horizontal
liga:
icon-dots-two-vertical
liga:
icon-download
liga:
icon-emoji-flirt
liga:
icon-flow-branch
liga:
icon-flow-cascade
liga:
icon-flow-line
liga:
icon-flow-parallel
liga:
icon-flow-tree
liga:
icon-install
liga:
icon-layers
liga:
icon-open-book
liga:
icon-resize-100
liga:
icon-resize-full-screen
liga:
icon-save
liga:
icon-select-arrows
liga:
icon-sound-mute
liga:
icon-sound
liga:
icon-trash
liga:
icon-triangle-down
liga:
icon-triangle-left
liga:
icon-triangle-right
liga:
icon-triangle-up
liga:
icon-uninstall
liga:
icon-upload-to-cloud
liga:
icon-upload
liga:
icon-add-user
liga:
icon-address
liga:
icon-adjust
liga:
icon-air
liga:
icon-aircraft-landing
liga:
icon-aircraft-take-off
liga:
icon-aircraft
liga:
icon-align-bottom
liga:
icon-align-horizontal-middle
liga:
icon-align-left
liga:
icon-align-right
liga:
icon-align-top
liga:
icon-align-vertical-middle
liga:
icon-archive
liga:
icon-area-graph
liga:
icon-attachment
liga:
icon-awareness-ribbon
liga:
icon-back-in-time
liga:
icon-back
liga:
icon-bar-graph
liga:
icon-battery
liga:
icon-beamed-note
liga:
icon-bell
liga:
icon-blackboard
liga:
icon-block
liga:
icon-book
liga:
icon-bowl
liga:
icon-box
liga:
icon-briefcase
liga:
icon-browser
liga:
icon-brush
liga:
icon-bucket
liga:
icon-cake
liga:
icon-calculator
liga:
icon-calendar
liga:
icon-camera
liga:
icon-ccw
liga:
icon-chat
liga:
icon-check
liga:
icon-circle-with-cross
liga:
icon-circle-with-minus
liga:
icon-circle-with-plus
liga:
icon-circle
liga:
icon-circular-graph
liga:
icon-clapperboard
liga:
icon-clipboard
liga:
icon-clock
liga:
icon-code
liga:
icon-cog
liga:
icon-colours
liga:
icon-compass
liga:
icon-copy
liga:
icon-credit-card
liga:
icon-credit
liga:
icon-cross
liga:
icon-cup
liga:
icon-cw
liga:
icon-cycle
liga:
icon-database
liga:
icon-dial-pad
liga:
icon-direction
liga:
icon-document
liga:
icon-documents
liga:
icon-drink
liga:
icon-drive
liga:
icon-drop
liga:
icon-edit
liga:
icon-email
liga:
icon-emoji-happy
liga:
icon-emoji-neutral
liga:
icon-emoji-sad
liga:
icon-erase
liga:
icon-eraser
liga:
icon-export
liga:
icon-eye
liga:
icon-feather
liga:
icon-flag
liga:
icon-flash
liga:
icon-flashlight
liga:
icon-flat-brush
liga:
icon-folder-images
liga:
icon-folder-music
liga:
icon-folder-video
liga:
icon-folder
liga:
icon-forward
liga:
icon-funnel
liga:
icon-game-controller
liga:
icon-gauge
liga:
icon-globe
liga:
icon-graduation-cap
liga:
icon-grid
liga:
icon-hair-cross
liga:
icon-hand
liga:
icon-heart-outlined
liga:
icon-heart
liga:
icon-help-with-circle
liga:
icon-help
liga:
icon-home
liga:
icon-hour-glass
liga:
icon-image-inverted
liga:
icon-image
liga:
icon-images
liga:
icon-inbox
liga:
icon-infinity
liga:
icon-info-with-circle
liga:
icon-info
liga:
icon-key
liga:
icon-keyboard
liga:
icon-lab-flask
liga:
icon-landline
liga:
icon-language
liga:
icon-laptop
liga:
icon-leaf
liga:
icon-level-down
liga:
icon-level-up
liga:
icon-lifebuoy
liga:
icon-light-bulb
liga:
icon-light-down
liga:
icon-light-up
liga:
icon-line-graph
liga:
icon-link
liga:
icon-list
liga:
icon-location-pin
liga:
icon-location
liga:
icon-lock-open
liga:
icon-lock
liga:
icon-log-out
liga:
icon-login
liga:
icon-loop
liga:
icon-magnet
liga:
icon-magnifying-glass
liga:
icon-mail
liga:
icon-man
liga:
icon-map
liga:
icon-mask
liga:
icon-medal
liga:
icon-megaphone
liga:
icon-menu
liga:
icon-message
liga:
icon-mic
liga:
icon-minus
liga:
icon-mobile
liga:
icon-modern-mic
liga:
icon-moon
liga:
icon-mouse
liga:
icon-music
liga:
icon-network
liga:
icon-new-message
liga:
icon-new
liga:
icon-news
liga:
icon-note
liga:
icon-notification
liga:
icon-old-mobile
liga:
icon-old-phone
liga:
icon-palette
liga:
icon-paper-plane
liga:
icon-pencil
liga:
icon-phone
liga:
icon-pie-chart
liga:
icon-pin
liga:
icon-plus
liga:
icon-popup
liga:
icon-power-plug
liga:
icon-price-ribbon
liga:
icon-price-tag
liga:
icon-print
liga:
icon-progress-empty
liga:
icon-progress-full
liga:
icon-progress-one
liga:
icon-progress-two
liga:
icon-publish
liga:
icon-quote
liga:
icon-radio
liga:
icon-reply-all
liga:
icon-reply
liga:
icon-retweet
liga:
icon-rocket
liga:
icon-round-brush
liga:
icon-rss
liga:
icon-ruler
liga:
icon-scissors
liga:
icon-share-alternitive
liga:
icon-share
liga:
icon-shareable
liga:
icon-shield
liga:
icon-shop
liga:
icon-shopping-bag
liga:
icon-shopping-basket
liga:
icon-shopping-cart
liga:
icon-shuffle
liga:
icon-signal
liga:
icon-sound-mix
liga:
icon-sports-club
liga:
icon-spreadsheet
liga:
icon-squared-cross
liga:
icon-squared-minus
liga:
icon-squared-plus
liga:
icon-star-outlined
liga:
icon-star
liga:
icon-stopwatch
liga:
icon-suitcase
liga:
icon-swap
liga:
icon-sweden
liga:
icon-switch
liga:
icon-tablet
liga:
icon-tag
liga:
icon-text-document-inverted
liga:
icon-text-document
liga:
icon-text
liga:
icon-thermometer
liga:
icon-thumbs-down
liga:
icon-thumbs-up
liga:
icon-thunder-cloud
liga:
icon-ticket
liga:
icon-time-slot
liga:
icon-tools
liga:
icon-traffic-cone
liga:
icon-tree
liga:
icon-trophy
liga:
icon-tv
liga:
icon-typing
liga:
icon-unread
liga:
icon-untag
liga:
icon-user
liga:
icon-users
liga:
icon-v-card
liga:
icon-video
liga:
icon-vinyl
liga:
icon-voicemail
liga:
icon-wallet
liga:
icon-water
liga:
icon-px-with-circle
liga:
icon-px
liga:
icon-basecamp
liga:
icon-behance
liga:
icon-creative-cloud
liga:
icon-dropbox
liga:
icon-evernote
liga:
icon-flattr
liga:
icon-foursquare
liga:
icon-google-drive
liga:
icon-google-hangouts
liga:
icon-grooveshark
liga:
icon-icloud
liga:
icon-mixi
liga:
icon-onedrive
liga:
icon-paypal
liga:
icon-picasa
liga:
icon-qq
liga:
icon-rdio-with-circle
liga:
icon-renren
liga:
icon-scribd
liga:
icon-sina-weibo
liga:
icon-skype-with-circle
liga:
icon-skype
liga:
icon-slideshare
liga:
icon-smashing
liga:
icon-soundcloud
liga:
icon-spotify-with-circle
liga:
icon-spotify
liga:
icon-swarm
liga:
icon-vine-with-circle
liga:
icon-vine
liga:
icon-vk-alternitive
liga:
icon-vk-with-circle
liga:
icon-vk
liga:
icon-xing-with-circle
liga:
icon-xing
liga:
icon-yelp
liga:
icon-dribbble-with-circle
liga:
icon-dribbble
liga:
icon-facebook-with-circle
liga:
icon-facebook
liga:
icon-flickr-with-circle
liga:
icon-flickr
liga:
icon-github-with-circle
liga:
icon-github
liga:
icon-google-with-circle
liga:
icon-google
liga:
icon-instagram-with-circle
liga:
icon-instagram
liga:
icon-lastfm-with-circle
liga:
icon-lastfm
liga:
icon-linkedin-with-circle
liga:
icon-linkedin
liga:
icon-pinterest-with-circle
liga:
icon-pinterest
liga:
icon-rdio
liga:
icon-stumbleupon-with-circle
liga:
icon-stumbleupon
liga:
icon-tumblr-with-circle
liga:
icon-tumblr
liga:
icon-twitter-with-circle
liga:
icon-twitter
liga:
icon-vimeo-with-circle
liga:
icon-vimeo
liga:
icon-youtube-with-circle
liga:
icon-youtube
liga:

# Grid Size: 24

icon-eye2
liga:
icon-paper-clip
liga:
icon-mail2
liga:
icon-toggle
liga:
icon-layout
liga:
icon-link2
liga:
icon-bell2
liga:
icon-lock2
liga:
icon-unlock
liga:
icon-ribbon
liga:
icon-image2
liga:
icon-signal2
liga:
icon-target
liga:
icon-clipboard2
liga:
icon-clock2
liga:
icon-watch
liga:
icon-air-play
liga:
icon-camera2
liga:
icon-video2
liga:
icon-disc
liga:
icon-printer
liga:
icon-monitor
liga:
icon-server
liga:
icon-cog2
liga:
icon-heart2
liga:
icon-paragraph
liga:
icon-align-justify
liga:
icon-align-left2
liga:
icon-align-center
liga:
icon-align-right2
liga:
icon-book2
liga:
icon-layers2
liga:
icon-stack
liga:
icon-stack-2
liga:
icon-paper
liga:
icon-paper-stack
liga:
icon-search
liga:
icon-zoom-in
liga:
icon-zoom-out
liga:
icon-reply2
liga:
icon-circle-plus
liga:
icon-circle-minus
liga:
icon-circle-check
liga:
icon-circle-cross
liga:
icon-square-plus
liga:
icon-square-minus
liga:
icon-square-check
liga:
icon-square-cross
liga:
icon-microphone
liga:
icon-record
liga:
icon-skip-back
liga:
icon-rewind
liga:
icon-play
liga:
icon-pause
liga:
icon-stop
liga:
icon-fast-forward
liga:
icon-skip-forward
liga:
icon-shuffle2
liga:
icon-repeat
liga:
icon-folder2
liga:
icon-umbrella
liga:
icon-moon2
liga:
icon-thermometer2
liga:
icon-drop2
liga:
icon-sun
liga:
icon-cloud2
liga:
icon-cloud-upload
liga:
icon-cloud-download
liga:
icon-upload2
liga:
icon-download2
liga:
icon-location2
liga:
icon-location-2
liga:
icon-map2
liga:
icon-battery2
liga:
icon-head
liga:
icon-briefcase2
liga:
icon-speech-bubble
liga:
icon-anchor
liga:
icon-globe2
liga:
icon-box2
liga:
icon-reload
liga:
icon-share2
liga:
icon-marquee
liga:
icon-marquee-plus
liga:
icon-marquee-minus
liga:
icon-tag2
liga:
icon-power
liga:
icon-command
liga:
icon-alt
liga:
icon-esc
liga:
icon-bar-graph2
liga:
icon-bar-graph-2
liga:
icon-pie-graph
liga:
icon-star2
liga:
icon-arrow-left2
liga:
icon-arrow-right2
liga:
icon-arrow-up2
liga:
icon-arrow-down2
liga:
icon-volume
liga:
icon-mute
liga:
icon-content-right
liga:
icon-content-left
liga:
icon-grid2
liga:
icon-grid-2
liga:
icon-columns
liga:
icon-loader
liga:
icon-bag
liga:
icon-ban
liga:
icon-flag2
liga:
icon-trash2
liga:
icon-expand
liga:
icon-contract
liga:
icon-maximize
liga:
icon-minimize
liga:
icon-plus2
liga:
icon-minus2
liga:
icon-check2
liga:
icon-cross2
liga:
icon-move
liga:
icon-delete
liga:
icon-menu2
liga:
icon-archive2
liga:
icon-inbox2
liga:
icon-outbox
liga:
icon-file
liga:
icon-file-add
liga:
icon-file-subtract
liga:
icon-help2
liga:
icon-open
liga:
icon-ellipsis
liga:

# Font Test Drive

Font Size: px

Generated by IcoMoon